@@ -21,6 +21,10 @@ ALL_SITES = get_all_sites()  # All the Craiglist sites
 RESULTS_PER_REQUEST = 100  # Craigslist returns 100 results per request
 
 
+def bs(content):
+    return BeautifulSoup(content, 'html.parser')
+
+
 def requests_get(*args, **kwargs):
     """
     Retries if a RequestException is raised (could be a connection error or
@@ -39,7 +43,7 @@ def requests_get(*args, **kwargs):
 def get_list_filters(url):
     list_filters = {}
     response = requests_get(url)
-    soup = BeautifulSoup(response.content, 'html.parser')
+    soup = bs(response.content)
     for list_filter in soup.find_all('div', class_='search-attribute'):
         filter_key = list_filter.attrs['data-attr']
         filter_labels = list_filter.find_all('label')
@@ -65,6 +69,7 @@ class CraigslistBase(object):
         'search_titles': {'url_key': 'srchType', 'value': 'T'},
         'has_image': {'url_key': 'hasPic', 'value': 1},
         'posted_today': {'url_key': 'postedToday', 'value': 1},
+        'bundle_duplicates': {'url_key': 'bundleDuplicates', 'value': 1},
         'search_distance': {'url_key': 'search_distance', 'value': None},
         'zip_code': {'url_key': 'postal', 'value': None},
     }
@@ -149,11 +154,12 @@ class CraigslistBase(object):
         base_url = self.url_templates['base']
         response = requests_get(base_url % {'site': self.site},
                                 logger=self.logger)
-        soup = BeautifulSoup(response.content, 'html.parser')
+        soup = bs(response.content)
         sublinks = soup.find('ul', {'class': 'sublinks'})
         return sublinks and sublinks.find('a', text=area) is not None
 
-    def get_results(self, limit=None, start=0, sort_by=None, geotagged=False):
+    def get_results(self, limit=None, start=0, sort_by=None, geotagged=False,
+                    include_details=False):
         """
         Get results from Craigslist based on the specified filters.
 
@@ -182,19 +188,23 @@ class CraigslistBase(object):
             self.logger.info('Response code: %s', response.status_code)
             response.raise_for_status()  # Something failed?
 
-            soup = BeautifulSoup(response.content, 'html.parser')
+            soup = bs(response.content)
             if not total:
                 totalcount = soup.find('span', {'class': 'totalcount'})
                 total = int(totalcount.text) if totalcount else 0
 
-            for row in soup.find_all('p', {'class': 'result-info'}):
+            rows = soup.find('ul', {'class': 'rows'})
+            for row in rows.find_all('li', {'class': 'result-row'},
+                                     recursive=False):
                 if limit is not None and results_yielded >= limit:
                     break
                 self.logger.debug('Processing %s of %s results ...',
                                   total_so_far + 1, total)
 
+                id = row.attrs['data-pid']
+                repost_of = row.attrs.get('data-repost-of')
+
                 link = row.find('a', {'class': 'hdrlnk'})
-                id = link.attrs['data-id']
                 name = link.text
                 url = urljoin(self.url, link.attrs['href'])
 
@@ -212,6 +222,7 @@ class CraigslistBase(object):
                 tags = tags_span.text if tags_span else ''
 
                 result = {'id': id,
+                          'repost_of': repost_of,
                           'name': name,
                           'url': url,
                           'datetime': datetime,
@@ -225,8 +236,12 @@ class CraigslistBase(object):
                 if self.custom_result_fields:
                     self.customize_result(result, row)
 
-                if geotagged and result['has_map']:
-                    self.geotag_result(result)
+                if (geotagged and result['has_map']) or include_details:
+                    detail_soup = self.fetch_content(result['url'])
+                    if geotagged and result['has_map']:
+                        self.geotag_result(result, detail_soup)
+                    if include_details:
+                        self.include_details(result, detail_soup)
 
                 yield result
                 results_yielded += 1
@@ -242,25 +257,51 @@ class CraigslistBase(object):
         """ Add custom/delete/alter fields to result. """
         pass  # Override in subclass to add category-specific fields.
 
-    def geotag_result(self, result):
+    def geotag_result(self, result, soup):
         """ Adds (lat, lng) to result. """
 
         self.logger.debug('Geotagging result ...')
 
-        if result['has_map']:
-            response = requests_get(result['url'], logger=self.logger)
-            self.logger.info('GET %s', response.url)
-            self.logger.info('Response code: %s', response.status_code)
-
-            if response.ok:
-                soup = BeautifulSoup(response.content, 'html.parser')
-                map = soup.find('div', {'id': 'map'})
-                if map:
-                    result['geotag'] = (float(map.attrs['data-latitude']),
-                                        float(map.attrs['data-longitude']))
+        map = soup.find('div', {'id': 'map'})
+        if map:
+            result['geotag'] = (float(map.attrs['data-latitude']),
+                                float(map.attrs['data-longitude']))
 
         return result
 
+    def include_details(self, result, soup):
+        """ Adds description, images to result """
+
+        self.logger.debug('Adding details to result...')
+
+        body = soup.find('section', id='postingbody')
+        # We need to massage the data a little bit because it might include
+        # some inner elements that we want to ignore.
+        body_text = (getattr(e, 'text', e) for e in body
+                     if not getattr(e, 'attrs', None))
+        result['body'] = ''.join(body_text).strip()
+
+        image_tags = soup.find_all('img')
+        # If there's more than one picture, the first one will be repeated.
+        image_tags = image_tags[1:] if len(image_tags) > 1 else image_tags
+
+        images = []
+        for img in image_tags:
+            img_link = img['src'].replace('50x50c', '600x450')
+            images.append(img_link)
+
+        result['images'] = images
+
+    def fetch_content(self, url):
+        response = requests_get(url, logger=self.logger)
+        self.logger.info('GET %s', response.url)
+        self.logger.info('Response code: %s', response.status_code)
+
+        if response.ok:
+            return bs(response.content)
+
+        return None
+
     def geotag_results(self, results, workers=8):
         """
         Add (lat, lng) to each result. This process is done using N threads,
