@@ -1,11 +1,12 @@
 from bs4 import BeautifulSoup
 import requests
 
-sites_url = 'http://www.craigslist.org/about/sites'
+ALL_SITES_URL = 'http://www.craigslist.org/about/sites'
+SITE_URL = 'http://%s.craigslist.org'
 
 
 def get_all_sites():
-    response = requests.get(sites_url)
+    response = requests.get(ALL_SITES_URL)
     response.raise_for_status()  # Something failed?
     soup = BeautifulSoup(response.content, 'html.parser')
     sites = set()
@@ -17,3 +18,12 @@ def get_all_sites():
             sites.add(site)
 
     return sites
+
+
+def get_all_areas(site):
+    response = requests.get(SITE_URL % site)
+    response.raise_for_status()  # Something failed?
+    soup = BeautifulSoup(response.content, 'html.parser')
+    raw = soup.select('ul.sublinks li a')
+    sites = set(a.attrs['href'].rsplit('/')[1] for a in raw)
+    return sites
